@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: configparser.h,v 1.16 2002/03/13 21:32:23 malte Exp $
+// $Id: configparser.h,v 1.16.4.1 2002/11/28 04:48:23 staikos Exp $
 
 #ifndef _CONFIGPARSER_H_
 #define _CONFIGPARSER_H_
@@ -463,6 +463,22 @@ namespace Config
 		ExpressionNode *m_exp2;
 	};
 
+	class ImplicitExpressionNode : public ExpressionNode
+	{
+	public:
+		ImplicitExpressionNode(VariableNode *v)
+			: m_v(v) {};
+		virtual ~ImplicitExpressionNode() { delete m_v; }
+
+		virtual bool evaluate() const
+		{
+			return !m_v->value().isEmpty() && !m_v->value().isNull();
+		}
+
+	private:
+		VariableNode *m_v;
+	};
+
 	class EqualityExpressionNode : public ExpressionNode
 	{
 	public:
