@@ -33,7 +33,7 @@
 #include "kticon.h"
 
 KTTask::KTTask(CTTask* _cttask, const QString & _caption)
-  : KDialog( 0, "kttask", true, WStyle_DialogBorder )
+       :KDialog( 0, "kttask", true, WStyle_DialogBorder )
 {
   cttask = _cttask;
 
@@ -134,7 +134,7 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   QVBoxLayout *v1 = new QVBoxLayout( h4, KDialogBase::spacingHint() );
 
   // days of the month
-  bgDayOfMonth = new QButtonGroup( i18n("Days of the Month"), this, "bgDayOfMonth");
+  bgDayOfMonth = new QButtonGroup( i18n("Days of Month"), this, "bgDayOfMonth");
   v1->addWidget( bgDayOfMonth );
 
   QPushButton* day;
@@ -162,7 +162,7 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   hdays->addStretch( 1 );
 
   // days of the week
-  bgDayOfWeek = new QButtonGroup( i18n("Days of the Week"), this, "bgDayOfWeek");
+  bgDayOfWeek = new QButtonGroup( i18n("Days of Week"), this, "bgDayOfWeek");
   v1->addWidget( bgDayOfWeek );
 
   QVBoxLayout *v3 = new QVBoxLayout( bgDayOfWeek, KDialogBase::spacingHint() );
@@ -187,7 +187,7 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   QVBoxLayout *v9 = new QVBoxLayout( bgEveryDay, KDialogBase::spacingHint() );
   v9->addSpacing( 2 * KDialogBase::spacingHint() );
 
-  cbEveryDay = new QCheckBox( i18n("Run Every Day"), bgEveryDay, "cbEveryDay");
+  cbEveryDay = new QCheckBox( i18n("Run every day"), bgEveryDay, "cbEveryDay");
   cbEveryDay->setChecked(everyDay);
   v9->addWidget( cbEveryDay );
 
@@ -298,6 +298,7 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   key_accel->readSettings();
 
   setFixedSize( minimumSize() );
+  slotDailyChanged();
 }
 
 KTTask::~KTTask()
