@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -68,13 +69,13 @@ void Archive::read( int version )
     char *buf = new char[ival + 1];
     buf[ival] = '\0';
     fread( buf, sizeof( char ), ival, _fptr );
-    _name = buf;    
+    _name = buf;
     delete [] buf;
 
     // Archive creation time (4 bytes).
     fread( &ival, sizeof( ival ), 1, _fptr );
     _ctime = ival;
-    
+
     // Archive ending block (4 bytes).
     fread( &ival, sizeof( ival ), 1, _fptr );
     _endBlock = ival;
@@ -92,10 +93,10 @@ void Archive::read( int version )
             _ranges.addRange( start, end );
         }
     }
-    
+
     // Number of immediate children (4 bytes).
     fread( &ival, sizeof( ival ), 1, _fptr );
-    
+
     //===== Read files =====
     for ( int count = ival; count > 0; count-- ) {
         fread( &ival, sizeof( ival ), 1, _fptr );
@@ -107,7 +108,7 @@ void Archive::readAll( int version )
 {
     read( version );
 
-    QListIterator<File> i( getChildren() );
+    QPtrListIterator<File> i( getChildren() );
     for ( ; i.current(); ++i ) {
         i.current()->readAll( version );
     }
@@ -119,7 +120,7 @@ void Archive::write( FILE* fptr )
     _offset = ftell( _fptr );
 
     int zero = 0;
-    
+
     // Archive name (4 bytes + n chars).
     int ival = 4096;
     fwrite( &ival, sizeof( ival ), 1, _fptr );
@@ -127,11 +128,11 @@ void Archive::write( FILE* fptr )
     memset( buf, 0, 4096 );
     memcpy( buf, _name.ascii(), _name.length() > 4095 ? 4095 : _name.length() );
     fwrite( buf, sizeof( char ), 4096, _fptr );
-    
+
     // Archive creation time (4 bytes).
     ival = getCTime();
     fwrite( &ival, sizeof( ival ), 1, _fptr );
-    
+
     // Archive ending block (4 bytes).
     ival = getEndBlock();
     fwrite( &ival, sizeof( ival ), 1, _fptr );
@@ -139,18 +140,18 @@ void Archive::write( FILE* fptr )
     // Child range list.
     ival = _ranges.getRanges().count();
     fwrite( &ival, sizeof( ival ), 1, _fptr );
-    QListIterator<Range> it( _ranges.getRanges() );
+    QPtrListIterator<Range> it( _ranges.getRanges() );
     for ( ; it.current(); ++it ) {
         ival = it.current()->getStart();
         fwrite( &ival, sizeof( ival ), 1, _fptr );
         ival = it.current()->getEnd();
         fwrite( &ival, sizeof( ival ), 1, _fptr );
     }
-    
+
     // Number of immediate children (4 bytes).
     ival = getChildren().count();
     fwrite( &ival, sizeof( ival ), 1, _fptr );
-    
+
     // Fill in file offsets later...
     int fileTable = ftell( _fptr );
     for ( ; ival > 0; ival-- ) {
@@ -158,7 +159,7 @@ void Archive::write( FILE* fptr )
     }
 
     //===== Write files =====
-    QListIterator<File> i( getChildren() );
+    QPtrListIterator<File> i( getChildren() );
     int count = 0;
     for ( ; i.current(); ++i, count++ ) {
         // Fill in the file offset.
@@ -174,7 +175,7 @@ void Archive::write( FILE* fptr )
 int Archive::getCTime()
 {
     read();
-    
+
     return _ctime;
 }
 
@@ -188,7 +189,7 @@ int Archive::getEndBlock()
 QString Archive::getName()
 {
     read();
-    
+
     return _name;
 }
 
@@ -197,14 +198,14 @@ Tape* Archive::getTape()
     return _tape;
 }
 
-const QList<File>& Archive::getChildren()
+const QPtrList<File>& Archive::getChildren()
 {
     read();
 
     return _children;
 }
 
-const QList<Range>& Archive::getRanges()
+const QPtrList<Range>& Archive::getRanges()
 {
     read();
 
@@ -239,6 +240,13 @@ void Archive::setName( const QString & name )
         fwrite( buf, sizeof( char ), 4096, _fptr );
         fflush( _fptr );
     }
+    /* 2002-01-31 LEW */
+#ifdef DEBUG
+    else {
+      printf("Archive::setName::_fptr is NULL. %s %d\n", __FILE__, __LINE__);
+    }
+#endif /* DEBUG */
+    /* 2002-01-31 LEW */
 
     TapeManager::instance()->tapeModified( _tape );
 }
@@ -246,7 +254,7 @@ void Archive::setName( const QString & name )
 void Archive::addChild( File* file )
 {
     read();
-    
+
     _children.append( file );
 }
 
@@ -272,7 +280,7 @@ File* Archive::addFile( int size, int mtime, int startRecord, int endRecord, con
     if ( path.count() == 0 ) {
         // Top level file/directory.
         file = new File( 0, size, mtime, startRecord, endRecord, fn );
-        
+
         addChild( file );
         return file;
     }
@@ -280,7 +288,7 @@ File* Archive::addFile( int size, int mtime, int startRecord, int endRecord, con
     QString dir = path.first();
     //path.remove(path.first());
     path.remove(path.begin());
-    QListIterator<File> i( getChildren() );
+    QPtrListIterator<File> i( getChildren() );
     File* parent = 0;
     for ( ; i.current() ; ++i ) {
         if ( i.current()->getName() == dir ) {
@@ -299,20 +307,20 @@ File* Archive::addFile( int size, int mtime, int startRecord, int endRecord, con
           ++j ) {
         QString dir = *j;
         File* pparent = parent;
-        QListIterator<File> i( pparent->getChildren() );
+        QPtrListIterator<File> i( pparent->getChildren() );
         for ( parent = 0; i.current() ; ++i ) {
             if ( i.current()->getName() == dir ) {
                 parent = i.current();
                 break;
             }
         }
-        
+
         if ( parent == 0 ) {
             parent = new File( pparent, 0, 0, 0, 0, dir );
             pparent->addChild( parent );
         }
     }
-    
+
     file = new File( parent, size, mtime, startRecord, endRecord, fn );
     parent->addChild( file );
 
@@ -325,21 +333,21 @@ void Archive::calcRanges()
 
     _ranges.clear();
 
-    QListIterator<File> it( getChildren() );
+    QPtrListIterator<File> it( getChildren() );
     for ( ; it.current(); ++it ) {
         it.current()->calcRanges();
-        QListIterator<Range> it2( it.current()->getRanges() );
+        QPtrListIterator<Range> it2( it.current()->getRanges() );
         for ( ; it2.current(); ++it2 ) {
             _ranges.addRange( it2.current()->getStart(), it2.current()->getEnd() );
         }
     }
-    
+
     //%%% This is a kludge to cope with a bug that I haven't found yet.
     //%%% If there is more than one range, then all of the ranges are merged
     //%%% into one big contiguous range.
     if ( _ranges.getRanges().count() > 1 ) {
         kdDebug() << "Archive::calcRanges() -- extra ranges detected, fixing..." << endl;
-        QListIterator<Range> iter( _ranges.getRanges() );
+        QPtrListIterator<Range> iter( _ranges.getRanges() );
         for ( ; iter.current(); ++iter ) {
             kdDebug() << "Archive::calcRanges() -- range = " << iter.current() << " to " << iter.current()->getEnd() << endl;
         }
@@ -349,7 +357,33 @@ void Archive::calcRanges()
         _ranges.addRange( start, end );
     }
 
+    /* 2002-01-26 LEW */
+    // printf("Ranges of tar files on tape (1):\n");
+    /* 2002-01-26 LEW */
     assert( _ranges.getRanges().count() <= 1 );
 
-    _endBlock = _ranges.getRanges().getFirst()->getEnd() / ( Options::instance()->getTapeBlockSize() / 512 );
+    /* 2002-01-26 LEW */
+    {
+#ifdef DEBUG
+#if 0  /* commented out because of compile warnings. Fix 'em if this is needed. */
+      Range *ptr;
+      // printf("Ranges of tar files on tape (2):\n");
+      for ( ptr = _ranges.getRanges().first(); 
+            ptr; 
+            ptr = _ranges.getRanges().next() ){
+	// printf("Range: start %d, end %d\n", ptr->getStart(), ptr->getEnd());
+      }
+#endif
+#endif /* DEBUG */
+      if( _ranges.getRanges().getFirst() == NULL ){
+	printf("There aren't any tar files on this tape as far as kdat can tell!\n");
+        _endBlock = 0;
+        return;
+      }
+    /* 2002-01-26 LEW */
+
+      _endBlock = _ranges.getRanges().getFirst()->getEnd() 
+                    /  ( Options::instance()->getTapeBlockSize() / 512 );
+    }
 }
+
