@@ -60,9 +60,9 @@ FormatOptDlg::FormatOptDlg( const QString & def, QWidget* parent, const char* na
     _tapeSizeUnits->insertItem( "MB" );
     _tapeSizeUnits->insertItem( "GB" );
 
-    QPushButton* ok     = new QPushButton( i18n( "OK" ), this );
+    QPushButton* ok     = new QPushButton( i18n( "&OK" ), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    QPushButton* cancel = new QPushButton( i18n( "Cancel" ), this );
+    QPushButton* cancel = new QPushButton( i18n( "&Cancel" ), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
