@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debInterface.cpp,v 1.55 2002/01/27 06:30:43 toivo Exp $
+//      $Id: debInterface.cpp,v 1.57.2.1 2002/12/13 15:20:21 toivo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -12,7 +12,7 @@
 #include <fcntl.h>		// for O_RDONLY
 #include <time.h>		// for localtime
 #include <setjmp.h>
-#include <iostream.h>
+#include <iostream>
 
 #include <kurl.h>
 #include <kglobal.h>
@@ -93,7 +93,7 @@ void DEB::listUnIPackages(QPtrList<packageInfo> *pki, LcacheObj *pCache)
   }
 }
 
-bool DEB::parseName(QString name, QString *n, QString *v)
+bool DEB::parseName(const QString &name, QString *n, QString *v)
 {
   int d1, d2, s1;
 
@@ -249,12 +249,15 @@ packageInfo *DEB::getUPackageInfo( const QString &name)
   packageInfo *pki = 0;
 
   QString s = "dpkg --info ";
+  s += "'";
   s += name;
+  s += "'";
+
   QStringList list =  kpty->run(s);
   for ( QStringList::Iterator it = list.begin();  it != list.end(); ++it ) {
     //    kdDebug() << "U=" << *it << "\n";
     if ((*it).find("Package:") >= 0) {
-      kdDebug() << "found\n";
+      //      kdDebug() << "found\n";
       while (it != list.begin()) {
 	list.remove(list.begin());
       }
@@ -263,7 +266,7 @@ packageInfo *DEB::getUPackageInfo( const QString &name)
   }
 
   if (list.count() > 1) {
-    pki = DEB::collectInfo(list);
+    pki = DEB::collectInfo(list, kpinterface[0]); // To be fixed up later, assumes order of kpinterface
     if (pki)
       pki->updated = TRUE;
   }
@@ -274,8 +277,12 @@ packageInfo *DEB::getUPackageInfo( const QString &name)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-packageInfo *DEB::collectInfo(QStringList &ln)
+packageInfo *DEB::collectInfo(QStringList &ln, pkgInterface *pkgInt)
 {
+  if (!pkgInt) {
+    pkgInt = this;
+  }
+
   QDict<QString> *a = new QDict<QString>;
   a->setAutoDelete(TRUE);
 
@@ -342,13 +349,13 @@ packageInfo *DEB::collectInfo(QStringList &ln)
     } else if (key == "installed-size") {
       a->insert("size",  new QString(val + "000"));
     } else {
-      //      printf("[%s=%s]\n",key.data(),val.data());
        a->insert(key, new QString(val));
     }
+    //    kdDebug() << "C=" << key << "," << val <<"\n";
   }
 
   if (haveName) {
-    packageInfo *i = new packageInfo(a,this);
+    packageInfo *i = new packageInfo(a,pkgInt);
     if (bad_install) {
       i->packageState = packageInfo::BAD_INSTALL;
     } else if (available) {
@@ -359,6 +366,7 @@ packageInfo *DEB::collectInfo(QStringList &ln)
     i->fixup();
     return i;
   } else {
+    delete a;
     return 0;
   }
 }
@@ -399,7 +407,9 @@ QStringList DEB::getIFileList(packageInfo *p)
 QStringList DEB::getUFileList(QString fn)
 {
   QString s = "dpkg --contents ";
+  s += "'";
   s += fn;
+  s += "'";
 
   QStringList filelist = kpty->run(s);
 
@@ -481,7 +491,9 @@ QString DEB::install(int installFlags, QPtrList<packageInfo> *p,
   for (i = p->first(); i!= 0; i = p->next())  {
     QString fname = i->fetchFilename();
     if (fname != "") {
+      packs += "'";
       packs += fname;
+      packs += "'";
       packs += " ";
     }
   }
