@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: fbsdInterface.cpp,v 1.34 2001/12/19 11:21:09 binner Exp $
+//      $Id: fbsdInterface.cpp,v 1.36 2002/08/15 16:06:16 binner Exp $
 //
 // Author: Alex Hayward
 // xelah@ferret.lmh.ox.ac.uk
@@ -43,9 +43,9 @@ fbsdInterface::fbsdInterface():pkgInterface() {
 
   locatedialog = new Locations(i18n("Location of BSD Packages and Ports"));
   locatedialog->dLocations(1, 1, this, i18n("Ports"), "Pkg", "*.tgz",
-                           i18n("Location of ports tree (eg /usr/ports or /usr/opt)"),FALSE);
+                           i18n("Location of Ports Tree (eg /usr/ports or /usr/opt)"),FALSE);
   locatedialog->dLocations(1, 6, this, i18n("Packages"), "Pkg", "*.tgz",
-                           i18n("Location of directories containing BSD packages or package trees"));
+                           i18n("Location of Directories Containing BSD Packages or Package Trees"));
   connect(locatedialog, SIGNAL(returnVal(LcacheObj *)), this, SLOT(setAvail(LcacheObj *)));
   locatedialog->apply_slot();
 
@@ -299,7 +299,7 @@ QStringList fbsdInterface::FindFile(const QString &) {
   return tmp;
 }
 
-bool fbsdInterface::parseName(QString name, QString *n, QString *v) {
+bool fbsdInterface::parseName(const QString &name, QString *n, QString *v) {
   int m1;
 
   m1 = name.findRev('-');
