@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: kissInterface.h,v 1.13 2001/09/26 16:33:31 mlaurent Exp $ 
+//      $Id: kissInterface.h,v 1.14 2002/06/07 11:44:59 coolo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -28,7 +28,7 @@ class KISS: public pkgInterface
 public:
   KISS();
   ~KISS();
-  
+
   bool isType(char *buf, const QString &fname);
   param *initinstallOptions();
   param *inituninstallOptions();
@@ -36,7 +36,7 @@ public:
   QStringList getFileList(packageInfo *p);
 
   QStringList FindFile(const QString &name);
-  bool parseName(QString name, QString *n, QString *v);
+  bool parseName(const QString& name, QString *n, QString *v);
 
 public slots:
   void setLocation();
@@ -45,7 +45,7 @@ public slots:
 private:
   packageInfo* collectInfo(const char *inp);
   void listInstalledPackages(QPtrList<packageInfo> *pki);
- 
+
   QString install(int installFlags, QPtrList<packageInfo> *plist, bool &test);
   QString uninstall(int uninstallFlags, QPtrList<packageInfo> *plist, bool &test);
 
