@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////
-//      $Id: kpPty.cpp,v 1.22.2.1 2002/05/16 15:23:59 toivo Exp $ 
+//      $Id: kpPty.cpp,v 1.26.2.1 2002/12/13 15:20:22 toivo Exp $ 
 // File  : kpackage.cpp
 // Author: Toivo Pedaste
 // 
@@ -114,6 +114,7 @@ bool kpPty::start(bool needRoot)
 QStringList kpPty::run(QString cmd, bool inLoop, bool needRoot)
 {
   bool quote = FALSE;
+  Result = 0;
   QString s;
 
   terminator.setPattern("RESULT=\\d+");
@@ -121,37 +122,41 @@ QStringList kpPty::run(QString cmd, bool inLoop, bool needRoot)
   gotPrompt = FALSE;
 
   if (hostName.isEmpty() && !started && (getuid() == 0 || !needRoot)) {
-    kdDebug() << "rRUN="<< cmd <<"\n";
+    kdDebug() << "CMD=\""<< cmd <<"\"\n";
     QStringList cl = QStringList::split(" ", cmd);
     QStrList cs;
     for ( QStringList::Iterator it = cl.begin(); it != cl.end(); ++it ) {
-      if ((*it).find('\'') >= 0) {
-	if (quote) {     // End of quoted string
-	  s += *it;
+      int lastPt = (*it).length() - 1;
+      if ((*it)[0] == '\'') { // Start of quoted string
+	s = *it;
+	if ((*it)[lastPt] == '\'') { // Also End of quoted string
 	  s.replace(QRegExp("'"),"");
 	  cs.append(s.latin1());
-	  //	  kdDebug() << "C=" << s << "\n";
+	  //	  kdDebug() << "C1=" << s << "\n";
 	  quote = FALSE;
-	} else {         // Start of quoted string
-	  s = *it;
+	} else {
 	  s += " ";
 	  quote = TRUE;
 	}
+      } else if ((*it)[lastPt] == '\'') { // End of quoted string
+	s += *it;
+	s.replace(QRegExp("'"),"");
+	cs.append(s.latin1());
+	//	kdDebug() << "C=" << s << "\n";
+	quote = FALSE;
+      }	else if (quote) {
+	s += *it;
+	s += " ";
       } else {
-	if (quote) {
-	  s += *it;
-	  s += " ";
-	} else {
-	  cs.append((*it).latin1());
-	  //	  kdDebug() << "Cc=" << *it << "\n";
-	}
+	cs.append((*it).latin1());
+	//	kdDebug() << "Cc=" << *it << "\n";
       }
     }
     int res = pty->run(cs.first(),cs,"dumb",FALSE);
-    kdDebug() << "res="<< res <<"\n";
+    // kdDebug() << "PTYrun="<< res <<"\n";
   } else {
     if (start(needRoot)) {
-      kdDebug() << "iRUN="<< cmd <<"\n";
+      kdDebug() << "CMDroot='"<< cmd <<"'\n";
       QString s = cmd + ";echo RESULT=$?\n";
       pty->send_bytes(s.ascii(),s.length());
     } else {
@@ -164,8 +169,6 @@ QStringList kpPty::run(QString cmd, bool inLoop, bool needRoot)
   if (inLoop) {
     eventLoop = TRUE;
     kapp->enter_loop();
-
-    kdDebug() << "R=" << retList.count() <<"\n";
     
     return retList;
   } else {
@@ -180,37 +183,41 @@ void kpPty::close() {
 
 void kpPty::finish(int ret)
 {
-  //  int num = retList.count();
-  //  kdDebug() << "kpPty::finish " << ret << "\n";
-  if (ret == -1) {
-    QStringList::Iterator l = retList.fromLast();
-    l--;
-    kdDebug() << "r=" << *l <<  "=\n";
-    int p;
-    if ((p = (*l).find("RESULT=")) >= 0) {
-      ret = (*l).mid(p+7).toInt(0,10);
-      //	 kdDebug() << "Ret=" << ret << "=" <<  (*l).mid(p+7) << ":" << num <<"\n";
-      //      kdDebug() << "R=" << *l << "\n";
-      retList.remove(l);                  // Remove return code
-    } else {
-      //      kdDebug() << "RR=" << *l << "\n";
-      ret = 666;
-    }
-	
+  //kdDebug() << "kpPty::finish " << ret << "\n";
+
+  QStringList::Iterator l;
+
+  if (ret == -1) {  // Called program executed
     if (!retList.empty()) {
       l = retList.fromLast();
       if ((*l).right(2) == "# ") {
 	retList.remove(l);                  // Remove prompt
       }
     }
-  }
-  
-  QStringList::Iterator l = retList.begin();
-  if ( l !=  retList.end()) {
-    retList.remove(l);                  // Remove command at start
+
+    if (!retList.empty()) {
+      int p;
+      l = retList.fromLast();
+      if ((p = (*l).find("RESULT=")) >= 0) {
+	ret = (*l).mid(p+7).toInt(0,10);
+	retList.remove(l);                  // Remove return code
+      } else {
+	ret = 666;
+      }
+    }
+
+    if (!retList.empty()) {
+      l = retList.begin();
+      if ( l !=  retList.end()) {
+	if ((*l).find("RESULT=") >= 0) {
+	  retList.remove(l);                  // Remove command at start
+	}
+      }
+    } 
   }
 
-  kdDebug() << "Ret=" << ret << "\n";
+  Result = ret;
+  kdDebug() << "Result=" << Result << " C=" << retList.count() << "\n";
   emit result(retList,ret);
 
   if (eventLoop) {
@@ -230,7 +237,7 @@ void kpPty::block_in(const char* txt, int len)
     unterm = TRUE;
   }
 
-  //   kdDebug() << "L=" << text << "\n";
+  // kdDebug() << "L=" << text << "\n";
 
   QString stext =  QString::fromLocal8Bit(text);
 
@@ -271,8 +278,6 @@ void kpPty::block_in(const char* txt, int len)
       //            kdDebug() << "PU=" << stext.length() << ":" <<sl.count() << "\n";
     }
 
-    //    kdDebug() << "s=[" << text << "]\n";
-    
     for ( QStringList::Iterator it = sl.begin(); it != sl.end(); ++it ) {
       //          kdDebug() << "L=" << *it << "\n";
       retList << (*it);
@@ -281,6 +286,7 @@ void kpPty::block_in(const char* txt, int len)
   pUnterm = unterm;
 
   if (stext.right(2) == "# ") {
+    //    kdDebug() << "ST=" << stext << "=\n";
     gotPrompt = TRUE;
     emit textIn("\r \n");
     finish(-1);
@@ -294,7 +300,7 @@ void kpPty::keyOut(char ch)
 
 void kpPty::done(int ret)
 {
-  kdDebug() << "Done\n";
+  //  kdDebug() << "Done\n";
 
   finish(ret);
 }
