@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.h,v 1.20 2001/09/26 16:33:31 mlaurent Exp $	
+// $Id: managementWidget.h,v 1.23 2002/10/09 15:19:03 toivo Exp $	
 // File  : managementWidget.h
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -42,7 +42,7 @@ class QSplitter;
 
 class managementWidget : public QFrame
 {
-  Q_OBJECT;
+  Q_OBJECT
 
   ///////////// METHODS ------------------------------------------------------
 public:
@@ -153,7 +153,6 @@ private:
   void setInstallAction(KAction *a) { install_action = a; }
   void setUninstallAction(KAction *a) { uninstall_action = a; }
 
- private slots:
  void packageHighlighted(QListViewItem *);
   // This is called when a package has been highlighted in the list tree
 
