@@ -1,5 +1,5 @@
-//////////////////////////////////////////////////////////////         
-// 	$Id: packageProperties.cpp,v 1.26 2001/02/13 16:28:50 toivo Exp $	
+//////////////////////////////////////////////////////////////
+// 	$Id: packageProperties.cpp,v 1.30 2002/10/08 14:49:39 toivo Exp $	
 //
 // Author: Toivo Pedaste
 //
@@ -14,7 +14,7 @@
 
 packagePropertiesWidget::packagePropertiesWidget
   (QWidget *parent)
-  : QTextBrowser(parent)
+  : KTextBrowser(parent)
 {
   QDict<QString> trl(53);
   QStringList  pList();
@@ -64,7 +64,7 @@ void packagePropertiesWidget::initTranslate()
   iList("priority", i18n("priority"));
 
   iList("essential", i18n("essential"));
-  iList("installtime", i18n("installtime"));
+  iList("install time", i18n("install time"));
   iList("config-version", i18n("config-version"));
   iList("distribution", i18n("distribution"));
   iList("vendor", i18n("vendor"));
@@ -122,7 +122,6 @@ void packagePropertiesWidget::changePackage(packageInfo *p)
 	propName = *pr;
       } else {
 	propName = *s;
-	kdDebug() << "Unknown=" << propName << "\n";
       }
       stmp += "<tr>";
       stmp += "<td VALIGN=TOP><b>";
@@ -219,10 +218,10 @@ void  packagePropertiesWidget::delement(QString f) {
 void  packagePropertiesWidget::setSource(const QString &name) {
   QString s = name;
 
-  if (s.left(5) == "file:") {
+  if (s.startsWith("file:")) {
     s = s.mid(5);
   }
-  if (s.left(1) == "/") {
+  else if (s.at(1) == '/') {
     s = s.mid(1);
   }
   QString ind = s + package->interface->typeID;
@@ -239,3 +238,4 @@ void  packagePropertiesWidget::setSource(const QString &name) {
     }
   }
 }
+#include "packageProperties.moc"
