@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-//      $Id: packageProperties.h,v 1.12 2001/09/02 20:30:08 bruggie Exp $ 
+//      $Id: packageProperties.h,v 1.14.2.2 2002/12/19 09:10:59 mlaurent Exp $
 // File  : packageProperties.h
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -16,23 +16,22 @@
 // Standard Headers
 
 // Qt Headers
-#include <qttableview.h>
 #include <qpainter.h>
-#include <qstringlist.h> 
-#include <qregexp.h> 
-#include <qtextbrowser.h> 
+#include <qstringlist.h>
+#include <qregexp.h>
 
 // KDE Headers
 #include <klocale.h>
+#include <ktextbrowser.h>
 
 // kpackage Headers
 #include "packageInfo.h"
 
 class packageInfo;
 
-class packagePropertiesWidget : public QTextBrowser
+class packagePropertiesWidget : public KTextBrowser
 {
-  Q_OBJECT;
+  Q_OBJECT
   ///////////// METHODS ------------------------------------------------------
 public:
 
@@ -54,7 +53,7 @@ protected:
   ///////////// DATA ---------------------------------------------------------
 private:
   packageInfo *package;
- 
+
   void initTranslate();
   void iList(QString txt, QString itxt);
 
