@@ -1,10 +1,11 @@
 //////////////////////////////////////////////////////////////
-//      $Id: pkgInterface.cpp,v 1.55 2001/10/10 15:14:27 toivo Exp $
+//      $Id: pkgInterface.cpp,v 1.56.2.1 2002/12/13 15:20:22 toivo Exp $
 //
 // Author: Toivo Pedaste
 //
 #include <klocale.h>
 #include <kglobal.h>
+#include <kdebug.h>
 #include <kiconloader.h>
 
 #include "kpackage.h"
@@ -86,16 +87,12 @@ QString pkgInterface::doInstall(int, QString, bool &) {return 0;}
 
 void pkgInterface::listPackages(QPtrList<packageInfo> *pki)
 {
-  QString s;
-  cacheObj *cp;
-
   listInstalledPackages(pki);
   if (packageLoc) {
-    for (cp = packageLoc->first(); cp != 0; cp = packageLoc->next()) {
-      s = getDir(cp);
-      if (s != "") {
-	listDir(pki, s, cp->location, cp->subdirs);
-      }
+    for (cacheObj *cp = packageLoc->first(); cp != 0; cp = packageLoc->next()) {
+      QString s = getDir(cp);
+      if (!s.isEmpty())
+          listDir(pki, s, cp->location, cp->subdirs);
     }
   }
 }
@@ -105,12 +102,17 @@ void pkgInterface::smerge(packageInfo *)
 
 void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString dir, bool subdirs)
 {
+  //  fname - path to directory or cached remote infromation file
+  //  dir - url of directory
+
   QString name, size, rfile;
   packageInfo *p;
 
   QString sline( queryMsg + fname );
   kpackage->setStatus(sline);
 
+  kdDebug() << "listDir fn=" << fname << " dir=" << dir << endl;
+
   QDir d(fname,packagePattern);
 
   if (subdirs)
@@ -128,8 +130,8 @@ void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString di
       while ( (fi=it.current()) ) {           // for each entry...
 	if ( fi->isDir() ) {
 	  // entry is a subdir
-	  if ( fi->fileName() != (const QString &)"." &&
-	       fi->fileName() != (const QString &)".." )
+	  if ( fi->fileName() != QString::fromLatin1(".") &&
+	       fi->fileName() != QString::fromLatin1("..") )
 	    {
 	      // not current dir and not parent dir
 	      // -> recursive call:
@@ -142,7 +144,7 @@ void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString di
 	} else {
 	  // entry is a file
 	  if (opts->PkgRead) {
-	    rfile = dir + "/";
+	    rfile = fname + "/";
 	    rfile += fi->fileName();
 	    p = getPackageInfo('u',rfile, 0);
 	    if (p) {
@@ -189,7 +191,8 @@ void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString di
 
 packageInfo *pkgInterface::collectDir(QString name, QString size, QString dir)
 {
-  QString n,v;
+    kdDebug() << "collectDir " << name << " " << size << " " << dir << endl;
+    QString n,v;
 
   if (parseName(name, &n, &v)) {
     QDict<QString> *a = new QDict<QString>;
@@ -246,26 +249,25 @@ QString pkgInterface::getPackList(cacheObj *cp)
 }
 
 QString pkgInterface::getDir(cacheObj *cp) {
-  QString string = "";
+
   int res;
   QString tmpDir;
-
   QString url = cp->location;
 
   if ((res = cacheObj::newDCache(url, cp->cacheFile, tmpDir))) {
     if (res < 0)
-      return string;
+      return QString::null;
 
     Kiod kiod;
-    if (kiod.listDir(url,tmpDir)) {
+    if (kiod.listDir(url,tmpDir, cp->subdirs)) {
       return tmpDir;
     } else {
       KpMsgE(i18n("Cannot read directory %1").arg(url),FALSE);
       unlink(tmpDir.ascii());
-      return string;
+      return QString::null;
     }
   } else {
-    return tmpDir;
+      return tmpDir;
   }
 }
 
