@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: updateLoc.h,v 1.16 2001/05/30 20:27:15 waba Exp $ 
+//      $Id: updateLoc.h,v 1.17 2002/04/22 18:47:07 arbab Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -106,7 +106,7 @@ private:
   QGroupBox *fbase;
   QVBoxLayout* vbase;
 
-  static const int PNUM = 40;
+  enum { PNUM = 40 };
   int numLines;
   dpanel *dp[PNUM];
   KComboBox *combo[PNUM];
@@ -146,7 +146,7 @@ void cLocations(int numberDirs, int numberLines,
 void restore();
 
 int numPanels;
-static const int PANNUM = 10;
+enum { PANNUM = 10 };
 updateLoc *pn[PANNUM];
 
 public slots:
