@@ -20,6 +20,9 @@
 #include <qdir.h>
 #include <qstring.h>
 
+#include <ktrader.h>
+#include <kservice.h>
+
 template<class T> class QValueList;
 class QFileInfo;
 class QDataStream;
@@ -31,9 +34,14 @@ namespace ksv
 {
   namespace IO
   {
-    void removeFile (const QFileInfo& info, QDir& dir, QString& rich, QString& plain);
+    void removeFile (const QFileInfo& info, QDir& dir,
+                     QString& rich, QString& plain);
+
     QString relToAbs (const QString& dir, const QString& rel);
-    void makeSymlink (const KSVData& data, int runlevel, bool start, QString& rich, QString& plain);
+
+    void makeSymlink (const KSVData& data, int runlevel, bool start,
+                      QString& rich, QString& plain);
+
     void dissectFilename (const QString& file, QString& name, int& nr);
 
     QString makeRelativePath (const QString& from, const QString& to);
@@ -45,6 +53,10 @@ namespace ksv
     bool loadSavedConfiguration (QDataStream&,
                                  QValueList<KSVData>* start,
                                  QValueList<KSVData>* stop);
+
+    KTrader::OfferList servicesForFile (const QString& filename);
+    KService::Ptr preferredServiceForFile (const QString& filename);
+
   }; // namespace IO
 }; // namespace ksv
 
