@@ -5,7 +5,7 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.107 2002/01/20 23:43:28 mhunter Exp $
+	$Id: TopWidget.cpp,v 1.110 2002/09/01 08:46:42 mlaurent Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
@@ -134,7 +134,7 @@ KSVTopLevel::KSVTopLevel()
   kapp->setMainWidget (this);
 
   setCaption(false);
-  
+
   initActions(); // order dependency
   mView = new KSVContent (mOpenWith->popupMenu(), this, "Content"); // order dependency
   initTools(); // order dependency
@@ -195,7 +195,7 @@ void KSVTopLevel::initTools()
   connect (mStopDlg, SIGNAL(doAction(const QString&)),
 		   mView, SLOT(editService(const QString&)));
   connect (mRestartDlg, SIGNAL(doAction(const QString&)),
-		   mView, SLOT(restartService(const QString&))); 
+		   mView, SLOT(restartService(const QString&)));
   connect (mEditDlg, SIGNAL(doAction(const QString&)),
 		   mView, SLOT(editService(const QString&)));
 
@@ -239,7 +239,7 @@ void KSVTopLevel::initActions ()
   mFilePrintLog->setEnabled (false);
 
   mFileQuit = KStdAction::quit(this, SLOT(close()), coll);
-  
+
   // setup Edit menu
   mEditUndo = KStdAction::undo(this, SLOT(editUndo()), coll);
   mEditUndo->setEnabled (false);
@@ -280,7 +280,7 @@ void KSVTopLevel::initActions ()
   mToolsStopService = new KToggleAction (i18n("&Stop Service..."), "ksysv_stop", 0,
                                          mStopDlg, SLOT (toggle()),
                                          coll, "ksysv_stop_service");
-  
+
   mToolsRestartService = new KToggleAction (i18n("&Restart Service..."), 0,
                                             mRestartDlg, SLOT (toggle()),
                                             coll, "ksysv_restart_service");
@@ -317,7 +317,7 @@ bool KSVTopLevel::queryExit() {
 
 void KSVTopLevel::slotClearChanges()
 {
-  if (mChanged && 
+  if (mChanged &&
       KMessageBox::Yes ==
       KMessageBox::questionYesNo(kapp->mainWidget(),
 				 i18n("Do you really want to revert all unsaved changes?"),
@@ -412,14 +412,14 @@ void KSVTopLevel::initStatusBar()
                                  "when you use the <strong>Save Options command</strong>.</p>"));
   QToolTip::add (visBox, i18n ("Show only the selected runlevels"));
 
-  new QLabel (i18n(" Show Runlevels: "), visBox, "visLabel");
+  new QLabel (i18n(" Show runlevels: "), visBox, "visLabel");
   for (int i = 0; i < ksv::runlevelNumber; ++i)
 	{
 	  QString label; label.setNum (i);
 
 	  mVisible[i] = new QCheckBox (label, visBox, label.latin1());
 	  mVisible[i]->setChecked (mConfig->showRunlevel (i));
-	  
+
 	  group->insert (mVisible[i]);
 	}
 
@@ -445,7 +445,7 @@ void KSVTopLevel::initStatusBar()
   status->addWidget (authIconBox, 0, false);
   status->insertItem ("", Status::Changed, 100);
   status->addWidget (visBox, 0, true);
-  
+
   status->setItemAlignment (Status::Changed, AlignLeft|AlignVCenter);
 }
 
@@ -454,7 +454,7 @@ void KSVTopLevel::slotShowConfig()
   if (!mPreferences)
     {
       mPreferences = KSVPreferences::self();
-      
+
       connect (mPreferences, SIGNAL (updateColors ()),
                this, SLOT (updateColors ()));
 
@@ -530,10 +530,10 @@ void KSVTopLevel::editCut() {
 	{
 	  KSVDrag* mime = new KSVDrag (*list->currentItem()->data(), 0L, 0L);
 	  kapp->clipboard()->setData (mime);
-	  
+
 	  KSVData data = *list->currentItem()->data();
 	  delete list->currentItem();
-		  
+
 	  mUndoList->push (new RemoveAction (list, &data));
 	  setChanged (true);
 	}
@@ -553,11 +553,11 @@ void KSVTopLevel::editCopy()
 void KSVTopLevel::editPaste()
 {
   KSVDragList* list = mView->getOrigin();
-  
+
   if (list)
     {
 	  KSVData data;
-	  
+
 	  if (KSVDrag::decodeNative (kapp->clipboard()->data(), data))
 		{
 		  KSVAction* action = 0L;
@@ -618,9 +618,9 @@ void KSVTopLevel::editUndo ()
 void KSVTopLevel::editRedo ()
 {
   KSVAction* action = mRedoList->top();
-  
+
   mRedoList->redoLast();
-  
+
   setChanged (true);
   mUndoList->push (action);
 }
@@ -634,9 +634,9 @@ void KSVTopLevel::setPaste (bool val)
 void KSVTopLevel::setLog (bool val)
 {
   mConfig->setShowLog(val);
-  
+
   mOptionsToggleLog->setChecked (val);
-  
+
   mView->setDisplayScriptOutput(val);
 }
 
@@ -678,7 +678,7 @@ void KSVTopLevel::print()
 
 //   static QPrintDialog* dlg = new QPrintDialog (&prt, this, "KSysV Print Dialog");
 //   dlg->setCaption(kapp->makeStdCaption (i18n("Print")));
-  
+
 //   if (dlg->exec() == QDialog::Accepted)
 //     {
 //       int y = 10;
@@ -686,7 +686,7 @@ void KSVTopLevel::print()
 //       p.begin( &prt );
 
 //       QPaintDeviceMetrics metrics (&prt);
-  
+
 //       p.setFont (QFont("courier", 20, QFont::Bold));
 //       QFontMetrics fm = p.fontMetrics();
 
@@ -702,17 +702,17 @@ void KSVTopLevel::print()
 //         {
 //           p.setFont (QFont("courier", 16, QFont::Bold));
 //           QFontMetrics fm = p.fontMetrics();
-          
+
 //           p.drawText (10, y, i18n ("Runlevel %1").arg(i));
 //           y += fm.lineSpacing();
 
 //           checkPage
-          
+
 //           p.drawText (10, y, i18n ("Started Services"));
 //           y += fm.lineSpacing() * 2; // an extra empty line
 
 //        checkPage
-            
+
 //           p.setFont (QFont("courier", 10));
 //           fm = p.fontMetrics();
 
@@ -735,9 +735,9 @@ void KSVTopLevel::print()
 //           y += fm.lineSpacing(); // an extra empty line
 //           p.drawText (10, y, i18n ("Stopped Services"));
 //           y += fm.lineSpacing() * 2; // an extra empty line
-   
+
 //        checkPage
-       
+
 //           p.setFont (QFont("courier", 10));
 //           fm = p.fontMetrics();
 
@@ -764,7 +764,7 @@ void KSVTopLevel::print()
 //       //           ++it)
 //       //         {
 //       //           y += fm.ascent();
-          
+
 //       //           QString line = *it;
 //       //           if (line.isNull())
 //       //             line = " ";
@@ -772,28 +772,28 @@ void KSVTopLevel::print()
 //       //           line.replace( QRegExp("\t"), "        " );
 
 //       //           strncpy(buf,line.data(),160);
-          
+
 //       //           for (int j = 0 ; j <150; j++)
 //       //             {
 //       //               if (!isprint(buf[j]))
 //       //                 buf[j] = ' ';
 //       //             }
-          
+
 //       //           buf[line.length()] = '\0';
 //       //           p.drawText( 10, y, buf );
 //       //           y += fm.descent();
 //       //         }
-      
-//       p.end();        
+
+//       p.end();
 //     }
 }
 
 void KSVTopLevel::printLog()
-{  
+{
   KPrinter *prt = new KPrinter();
   prt->setDocName(kapp->aboutData()->programName() + " Log File");
   prt->setCreator(kapp->aboutData()->programName());
-  
+
   if (prt->setup(this))
     {
       KBusyManager::self()->setBusy (true);
@@ -802,14 +802,14 @@ void KSVTopLevel::printLog()
       QPaintDeviceMetrics pm (prt);
       const int height = pm.height();
       const int width = pm.width();
-      
+
       QStringList lines = QStringList::split ('\n', mView->xmlLog(), true);
       QStringList::Iterator line = lines.begin();
 
       int y = 0;
-      
+
       {
-        QSimpleRichText rheading (i18n("<h1>KDE Sys-V Init Editor Log</h1>"), 
+        QSimpleRichText rheading (i18n("<h1>KDE Sys-V Init Editor Log</h1>"),
                                   QFont("times"), QString::null, ksv::styleSheet(),
                                   QMimeSourceFactory::defaultFactory());
         rheading.setWidth (&p, width);
@@ -818,30 +818,30 @@ void KSVTopLevel::printLog()
         rheading.draw (&p, 0, y, region, colorGroup(), 0L);
 
         y += tmp_h;
-        
-        QSimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>").arg(QDateTime::currentDateTime().toString()), 
+
+        QSimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>").arg(QDateTime::currentDateTime().toString()),
                                QFont("times"), QString::null, ksv::styleSheet(),
                                QMimeSourceFactory::defaultFactory());
         rdate.setWidth (&p, width);
         tmp_h = rdate.height();
-	QRegion r2 (0, y, width, tmp_h); 
+	QRegion r2 (0, y, width, tmp_h);
         rdate.draw (&p, 0, y, r2, colorGroup(), 0L);
 
         y += tmp_h;
       }
 
       while (line != lines.end())
-        {         
+        {
           while (y < height)
             {
               QSimpleRichText rich (*line, QFont("times"), QString::null, ksv::styleSheet(),
                                     QMimeSourceFactory::defaultFactory());
               rich.setWidth (&p, width);
-              
+
               int tmp_h = rich.height();
               if (y + tmp_h > height)
                 break;
-              
+
               QRegion region (0, y, width, tmp_h);
               rich.draw (&p, 0, y, region, colorGroup(), 0L);
 
@@ -853,16 +853,17 @@ void KSVTopLevel::printLog()
 
               kapp->processEvents();
             }
-          
+
           prt->newPage();
           y = 0;
         }
 
     printing_finished:
-         
+
       p.end();
-      
+
       KBusyManager::self()->restore();
+      delete prt;
     }
 }
 
@@ -870,18 +871,18 @@ void KSVTopLevel::catchCannotGenerateNumber()
 {
   if (mConfig->showMessage (ksv::CouldNotGenerateSortingNumber)) {
     KMessageBox::information (kapp->mainWidget(),
-                              i18n ("<p>Sorry, I could not generate a valid " \
+                              i18n ("<p>Unable to generate a valid " \
                                     "sorting number for this position. This means " \
-                                    "that there was no number available in between "\
+                                    "that there was no number available between "\
                                     "the two adjacent services, and the service " \
                                     "did not fit in lexically.</p>" \
                                     "<p>Please adjust the sorting numbers manually "\
                                     "via the <strong>Properties dialog box</strong>.</p>"),
-                              i18n ("Could Not Generate Sorting Number"),
+                              i18n ("Unable to Generate Sorting Number"),
                               ksv::notifications[ksv::CouldNotGenerateSortingNumber]);
   }
 
-  statusBar()->message (i18n ("Could not generate sorting number. Please change manually."),
+  statusBar()->message (i18n ("Unable to generate sorting number. Please change manually."),
                         5000);
 }
 
@@ -925,7 +926,7 @@ void KSVTopLevel::dispatchEdit ()
       mEditCut->setEnabled (false);
       mEditProperties->setEnabled (false);
 	}
-  
+
   if (mView->scripts == list)
 	{
       mEditCut->setEnabled (false);
@@ -1005,7 +1006,7 @@ KActionCollection* KSVTopLevel::filteredActions ()
   // remove unwanted (internal) actions
   static KActionCollection coll = *actionCollection();
   static bool initialized = false;
-  
+
   if (!initialized)
     {
       coll.take(mPasteAppend);
@@ -1024,10 +1025,10 @@ void KSVTopLevel::configureKeys ()
 void KSVTopLevel::configureToolbars ()
 {
   KEditToolbar* dlg = new KEditToolbar (filteredActions(), xmlFile(), true, this);
-  
+
   if (dlg->exec())
     createGUI (xmlFile());
-  
+
   delete dlg;
 }
 
@@ -1101,12 +1102,12 @@ void KSVTopLevel::saveAs ()
     }
 
   file.close();
-  
+
   KBusyManager::self()->restore();
 }
 
 void KSVTopLevel::load ()
-{  
+{
   static const QString& filter = ksv::nativeFileFilter();
   QString filename = KFileDialog::getOpenFileName(0L, filter, this);
 
@@ -1120,7 +1121,7 @@ void KSVTopLevel::load ()
   QDataStream s (&file);
   QValueList<KSVData>* startLists = new QValueList<KSVData>[ksv::runlevelNumber];
   QValueList<KSVData>* stopLists = new QValueList<KSVData>[ksv::runlevelNumber];
-  
+
   if (ksv::IO::loadSavedConfiguration (s, startLists, stopLists))
     {
       statusBar()->message(i18n("Configuration package loaded successfully."), 5000);
