@@ -5,6 +5,7 @@
 #include <kdialog.h>
 #include <kfiledialog.h>
 #include <klineedit.h>
+#include <qpushbutton.h>
 
 /* 
  *  Constructs a KSVConfigWizard which is a child of 'parent', with the 
@@ -102,8 +103,8 @@ void KSVConfigWizard::chooseDistribution(int which)
       break;
 
     case SuSE:
-      rlpath = "/etc/rc.d"; //??
-      spath = "/sbin/init.d"; //??
+      rlpath = "/etc/rc.d";
+      spath = "/etc/init.d";
       break;
 
     default:
