@@ -26,12 +26,12 @@ private slots:
 
 private:
   typedef enum {
-    Debian,
-    RedHat,
-    Mandrake,
-    SuSE,
-    Corel,
-    Other
+    Debian=0,
+    RedHat=1,
+    SuSE=2,
+    Mandrake=3,
+    Corel=4,
+    Other=5
   } Distribution;
 
   Distribution mChosenDistribution;
