@@ -10,8 +10,6 @@
 
 class KUser;
 
-QString readentry(const QString &name, const QString def = QString::null);
-int readnumentry(const QString &name);
 void backup(const QString & name);
 char *updateString(char *d, const char *t);
 int getValue(long int &data, const QString & text, const QString & msg);
@@ -19,5 +17,7 @@ int getValue(int &data, const QString & text, const QString & msg);
 int getValue(unsigned int &data, const QString & text, const QString & msg);
 long today();
 int copyFile(const QString & from, const QString & to);
+QStringList readShells();
+void addShell(const QString &shell);
 
 #endif // _KU_MISC_H
