@@ -2,7 +2,7 @@
 #define _KU_MNT_H_
 
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class MntEnt {
 public:
@@ -14,11 +14,11 @@ public:
          const QString &aquotafilename);
   ~MntEnt();
 
-  const QString &getfsname() const;
-  const QString &getdir() const;
-  const QString &gettype() const;
-  const QString &getopts() const;
-  const QString &getquotafilename() const;
+  QString getfsname() const;
+  QString getdir() const;
+  QString gettype() const;
+  QString getopts() const;
+  QString getquotafilename() const;
 
   void setfsname(const QString &data);
   void setdir(const QString &data);
@@ -42,7 +42,7 @@ public:
   MntEnt *operator[](uint num);
   uint getMountsNumber();
 protected:
-  QList<MntEnt> m;
+  QPtrList<MntEnt> m;
 };
 
 #endif // _KU_MNT_H_
