@@ -1,4 +1,4 @@
-// $Id: propdlg.cpp,v 1.58 2002/02/25 03:18:06 jsinger Exp $
+// $Id: propdlg.cpp,v 1.63 2002/09/07 23:38:52 waba Exp $
 
 #include "globals.h"
 
@@ -8,8 +8,10 @@
 #include <qwhatsthis.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
+#include <qfile.h>
 
 #include <kseparator.h>
+#include <kmessagebox.h>
 #include <kglobal.h>
 
 #include <qvalidator.h>
@@ -143,53 +145,38 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     frontlayout = layout;
 
     leuser = new QLabel(frame);
-//    whatstr = i18n("WHAT IS THIS: User Login");
-    addRow(frame, layout, row++, leuser, i18n("User Login:"), whatstr, false);
+//    whatstr = i18n("WHAT IS THIS: User login");
+    addRow(frame, layout, row++, leuser, i18n("User login:"), whatstr, false);
 
     leid = new QLineEdit(frame);
 //    whatstr = i18n("WHAT IS THIS: User Id");
-    addRow(frame, layout, row++, leid, i18n("User Id:"), whatstr, false);
+    addRow(frame, layout, row++, leid, i18n("User ID:"), whatstr);
 
-    pbsetpwd = new QPushButton(i18n("Set Password"), frame);
-    layout->addMultiCellWidget(pbsetpwd, 0, 1, 2, 2, AlignBottom);
+    pbsetpwd = new QPushButton(i18n("Set Password..."), frame);
+    layout->addWidget(pbsetpwd, 0, 2);
     QObject::connect(pbsetpwd, SIGNAL(clicked()), this, SLOT(setpwd()));
 
     lefname = new QLineEdit(frame);
 //    whatstr = i18n("WHAT IS THIS: Full Name");
-    addRow(frame, layout, row++, lefname, i18n("Full Name:"), whatstr);
+    addRow(frame, layout, row++, lefname, i18n("Full name:"), whatstr);
     QObject::connect(lefname, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 
     leshell = new QComboBox(true, frame);
     leshell->clear();
     leshell->insertItem(i18n("<Empty>"));
 
-    QStringList shells;
-
-    FILE *f = fopen(SHELL_FILE,"r");
-    if (f) {
-      while (!feof(f)) {
-        char s[200];
-
-        fgets(s, 200, f);
-        if (feof(f))
-          break;
-
-        s[strlen(s)-1]=0;
-        if ((s[0])&&(s[0]!='#'))
-          shells.append(s);
-      }
-      fclose(f);
-    }
+    QStringList shells = readShells();
     shells.sort();
     leshell->insertStringList(shells);
     QObject::connect(leshell, SIGNAL(activated(const QString &)), this, SLOT(changed()));
+    QObject::connect(leshell, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Login Shell");
-    addRow(frame, layout, row++, leshell, i18n("Login Shell:"), whatstr);
+    addRow(frame, layout, row++, leshell, i18n("Login shell:"), whatstr);
 
     lehome = new QLineEdit(frame);
     QObject::connect(lehome, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Home Directory");
-    addRow(frame, layout, row++, lehome, i18n("Home Directory:"), whatstr);
+    addRow(frame, layout, row++, lehome, i18n("Home directory:"), whatstr);
 
 #ifdef EXTENDED_GECOS_BSD
     // FreeBSD appears to use the comma separated fields in the GECOS entry
@@ -237,7 +224,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     QDate lastChange = QDate(1970,1,1).addDays(user->getLastChange());
     leslstchg = new QLabel(frame);
     leslstchg->setText(KGlobal::locale()->formatDate(lastChange));
-    addRow(frame, layout, row++, leslstchg, i18n("Last Password Change:"), QString::null, true);
+    addRow(frame, layout, row++, leslstchg, i18n("Last password change:"), QString::null, true);
  
     layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
     row++;
@@ -245,7 +232,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     lesmin = addDaysGroup(frame, layout, row++, i18n("Password may not be changed before"), i18n("after last password change."), user->getMin(), false);
     lesmax = addDaysGroup(frame, layout, row++, i18n("Password expires"), i18n("after last password change."), user->getMax());
     leswarn = addDaysGroup(frame, layout, row++, i18n("Issue expire warning"), i18n("before password expires."), user->getWarn());
-    lesinact = addDaysGroup(frame, layout, row++, i18n("Account will be disabled"), i18n("after expiration of password"), user->getInactive());
+    lesinact = addDaysGroup(frame, layout, row++, i18n("Account will be disabled"), i18n("after expiration of password."), user->getInactive());
 
     layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
     row++;
@@ -274,7 +261,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     {
       QGroupBox *group = new QGroupBox( frame );
       layout->addMultiCellWidget(group, 1, 1, 0, 1);
-      group->setTitle("Disk Space");
+      group->setTitle(i18n("Disk Space"));
       QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint()); 
       groupLayout->addRowSpacing(0, group->fontMetrics().lineSpacing());
       groupLayout->setColStretch(0,1);
@@ -309,7 +296,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     {
       QGroupBox *group = new QGroupBox( frame );
       layout->addMultiCellWidget(group, 2, 2, 0, 1);
-      group->setTitle("Number of Files");
+      group->setTitle(i18n("Number of Files"));
       QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint()); 
       groupLayout->addRowSpacing(0, group->fontMetrics().lineSpacing());
       groupLayout->setColStretch(0,1);
@@ -350,12 +337,12 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 
 //    whatstr = i18n("WHATSTHIS: Primary Group");
     cbpgrp = new QComboBox(false, frame, "cbpgrp");
-    addRow(frame, layout, row++, cbpgrp, i18n("Primary Group:"), whatstr, false);
+    addRow(frame, layout, row++, cbpgrp, i18n("Primary group:"), whatstr, false);
     QObject::connect(cbpgrp, SIGNAL(activated(const QString &)), this, SLOT(setpgroup(const QString &)));
 
     lstgrp = new KListView(frame);
     lstgrp->setFullWidth(); // Single column, full widget width.
-    lstgrp->addColumn(i18n("Groups user '%1' belongs to:").arg(user->getName()));
+    lstgrp->addColumn(i18n("Groups User '%1' Belongs To").arg(user->getName()));
 //    QString whatstr = i18n("Select the groups that this user belongs to.");
     QWhatsThis::add(lstgrp, whatstr);
     layout->addMultiCellWidget(lstgrp, row, row, 0, 1);
@@ -435,7 +422,6 @@ void propdlg::setpgroup(const QString &) {
      QString groupName = item->text();
      if (groupName  == prevPrimaryGroup)
      {
-        KGroup *group = kug->getGroups().lookup(groupName);
         item->setEnabled(true);
         item->setOn(prevPrimaryGroupWasOn);
         item->repaint();
@@ -487,10 +473,11 @@ void propdlg::save() {
 #endif
 
   user->setHomeDir(lehome->text());
-  if (leshell->currentItem() != 0)
-    user->setShell(leshell->text(leshell->currentItem()));
+  if (leshell->currentItem() == 0)
+    user->setShell(QString::null);
   else
-    user->setShell("");
+    user->setShell(leshell->currentText());
+  // TODO: Check shell.
 
 #ifdef HAVE_SHADOW
   if (is_shadow) {
@@ -581,6 +568,14 @@ void propdlg::mntsel(int) {
 }
 #endif
 
+bool propdlg::checkShell(const QString &shell)
+{
+   if (shell.isEmpty())
+      return true;
+   QStringList shells = readShells();
+   return shells.contains(shell);
+}
+
 bool propdlg::check() {
   bool ret = false;
 
@@ -607,7 +602,7 @@ bool propdlg::check() {
 void propdlg::selectuser() {
   leuser->setText(user->getName());
 
-  leid->setText(QString("%1").arg(user->getUID()));
+  leid->setText(QString::fromLatin1("%1").arg(user->getUID()));
   olduid = user->getUID();
 
 //  sprintf(uname, "%i", user->getp_gid());
@@ -615,16 +610,17 @@ void propdlg::selectuser() {
 
   lefname->setText(user->getFullName());
 
-  if (user->getShell().isEmpty() != TRUE) {
+  oldshell = user->getShell();
+  if (!oldshell.isEmpty()) {
     bool tested = FALSE;
     for (int i=0; i<leshell->count(); i++)
-      if (leshell->text(i) == user->getShell()) {
+      if (leshell->text(i) == oldshell) {
         tested = TRUE;
         leshell->setCurrentItem(i);
         break;
       }
     if (!tested) {
-      leshell->insertItem(user->getShell());
+      leshell->insertItem(oldshell);
       leshell->setCurrentItem(leshell->count()-1);
     }
   } else
@@ -650,16 +646,17 @@ void propdlg::selectuser() {
       q = chquota;
 
       QuotaMnt *qm = (*quota)[q];
-      leqfs->setText(QString("%1").arg(qm->getfsoft()));
-      leqfh->setText(QString("%1").arg(qm->getfhard()));
-      leqis->setText(QString("%1").arg(qm->getisoft()));
-      leqih->setText(QString("%1").arg(qm->getihard()));
-      leqfcur->setText(QString("%1").arg(qm->getfcur()));
-      leqicur->setText(QString("%1").arg(qm->geticur()));
+      QString tmp = QString::fromLatin1("%1");
+      leqfs->setText(tmp.arg(qm->getfsoft()));
+      leqfh->setText(tmp.arg(qm->getfhard()));
+      leqis->setText(tmp.arg(qm->getisoft()));
+      leqih->setText(tmp.arg(qm->getihard()));
+      leqfcur->setText(tmp.arg(qm->getfcur()));
+      leqicur->setText(tmp.arg(qm->geticur()));
 
 #ifndef BSD
-      leqft->setText(QString("%1").arg(qm->getftime()));
-      leqit->setText(QString("%1").arg(qm->getitime()));
+      leqft->setText(tmp.arg(qm->getftime()));
+      leqit->setText(tmp.arg(qm->getitime()));
 #endif
     }
   }
@@ -679,11 +676,36 @@ void propdlg::slotOk() {
   uid_t newuid = leid->text().toInt();
 
   if (olduid != newuid)
+  {
     if (kug->getUsers().lookup(newuid)) {
       err->addMsg(i18n("User with UID %1 already exists").arg(newuid));
       err->display();
       return;
     }
+  }
+  
+  QString newshell;
+  if (leshell->currentItem() != 0)
+    newshell = leshell->currentText();
+  
+  if (oldshell != newshell)
+  {
+    if (!checkShell(newshell)) {
+      int result = KMessageBox::warningYesNoCancel(this,
+      		i18n("<p>The shell %1 is not yet listed in the file %2. "
+      		     "In order to use this shell you must add it to "
+      		     "this file first."
+      		     "<p>Do you want to add it now?").arg(newshell).arg(QFile::decodeName(SHELL_FILE)),
+      		i18n("Unlisted Shell"),
+      		i18n("&Add Shell"),
+      		i18n("Do &Not Add"));
+      	if (result == KMessageBox::Cancel)
+      	  return;
+      	
+      	if (result == KMessageBox::Yes)
+      	  addShell(newshell);
+    }
+  }
     
   if (check())
     accept();
