@@ -12,15 +12,15 @@ MailValidator::~MailValidator()
 }
 QValidator::State MailValidator::validate(QString &input, int &) const
 {
-	char c;
-	for(unsigned int i=0;i<strlen(input);i++) {
-		c=input.mid(i,1).latin1()[0];
+	QChar c;
+	for(unsigned int i=0;i<input.length();i++) {
+		c=input.at(i);
 		if(!isalnum(c) && c!='@' && c!='.' && c!='_' && c!='+' && c!='-')
 			return QValidator::Invalid;
 	}
 	if(input.find('@')!=input.findRev('@'))
 		return QValidator::Invalid;
-	if(input.mid(strlen(input)-1,1)=='@')
+	if(input.at(input.length()-1)=='@')
 		return QValidator::Acceptable;
 	return QValidator::Valid;
 }
