@@ -2,14 +2,10 @@
 #define UPLOADS_H
 
 #include "ftpaccess.h"
-#include "InputCtl.h"
-#include <qwidget.h>
-#include <qcheckbox.h>
+#include "UploadsBase.h"
 #include <kapp.h>
-#include <qlistbox.h>
-#include <qpushbutton.h>
 
-class Uploads : public QWidget {
+class Uploads : public UploadsBase {
 	Q_OBJECT
 public:
 	Uploads(QWidget *parent=0, const char *name=0);
@@ -25,10 +21,6 @@ public slots:
 private:
 	void	redraw();
 	ftpaccess *	ftpxs;
-	QListBox *	uploads;
-	QPushButton *	addUpload;
-	QPushButton *	editUpload;
-	QPushButton *	rmUpload;
 };
 
 #endif
