@@ -94,14 +94,14 @@ int String::locate(String const &s, bool cs, unsigned int startat) const
 	else
 		s2=strcasestr(s0+startat, s1);
 	if(s2==NULL) {
-		delete s0;
-		delete s1;
+		delete [] s0;
+		delete [] s1;
 		return -1;
 	}
 	r=(s2-s0);
 	if(startat>0) r++;
-	delete s0;
-	delete s1;
+	delete [] s0;
+	delete [] s1;
 	return r;
 }
 String const String::operator +(char const &s) {
@@ -136,8 +136,10 @@ String String::simplifyWhiteSpace() const {
 			s[i]=' ';
 	while(*s==' ')
 		strcpy(s, s+1);
-	while(s[strlen(s)-1]==' ')
-		s[strlen(s)-1]=0;
+	int l = strlen(s);
+	while(l && (s[l-1]==' '))
+		s[--l]=0;
+		
 	while(strstr(s, "  "))
 		strcpy(strstr(s, "  "), strstr(s, "  ")+1);
 	return s;
@@ -347,9 +349,9 @@ void StringList::sort(bool cs)
 	clear();
 	for(i=0; i<s; i++) {
 		insert(end(), strings[i]);
-		free(strings[i]);
+		delete [] strings[i];
 	}
-	delete strings;
+	delete [] strings;
 }
 StringList::operator String() const
 {
