@@ -12,7 +12,7 @@ EditWidget::EditWidget(QString const label, QString const text, bool isFile, QWi
 	connect(line, SIGNAL(returnPressed()), SIGNAL(returnPressed()));
 	lbl->setBuddy(line);
 	if(isFile) {
-		select=new QPushButton(_("Select"), this);
+		select=new QPushButton(_("Select..."), this);
 		connect(select, SIGNAL(clicked()), SLOT(selectFileClicked()));
 		select->resize(select->minimumSizeHint());
 		setStretchFactor(select, 0);
