@@ -22,16 +22,16 @@ General::General(liloconf *l, QWidget *parent, const char *name):QWidget(parent,
 	connect(drive, SIGNAL(activated(int)), SIGNAL(configChanged()));
 	layout->addWidget(drv);
 	QWhatsThis::add(drv, _("Select the drive or partition you want to install the LILO boot loader to here. Unless you intend to use other boot managers in addition to LILO, this should be the MBR (master boot record) of your boot drive.<br>In this case, you should probably select <i>/dev/hda</i> if your boot drive is an IDE drive or <i>/dev/sda</i> if your boot drive is SCSI."));
-	
+
 	QHBox *to=new QHBox(this);
-	QLabel *to_lbl=new QLabel(_("Boot the default kernel/OS &after "), to);
+	QLabel *to_lbl=new QLabel(_("Boot the default kernel/OS &after:"), to);
 	timeout=new QSpinBox(0, 1000000, 1, to);
 	timeout->setSuffix(_("/10 seconds"));
 	connect(timeout, SIGNAL(valueChanged(int)), SIGNAL(configChanged()));
 	to_lbl->setBuddy(timeout);
 	layout->addWidget(to);
 	QWhatsThis::add(to, _("LILO will wait the amount of time specified here before booting the kernel (or OS) marked as <i>default</i> in the <b>Images</b> tab."));
-	
+
 	QHBox *modes=new QHBox(this);
 	linear=new QCheckBox(_("Use &linear mode"), modes);
 	connect(linear, SIGNAL(clicked()), SIGNAL(configChanged()));
@@ -93,12 +93,15 @@ General::General(liloconf *l, QWidget *parent, const char *name):QWidget(parent,
 	vga->insertItem(_("VGA 1280x1024, 32767 colors (793)"));
 	vga->insertItem(_("VGA 1280x1024, 65536 colors (794)"));
 	vga->insertItem(_("VGA 1280x1024, 16.7M colors (795)"));
+        connect( vga, SIGNAL(activated ( int )), SIGNAL(configChanged()));
 	layout->addWidget(vgab);
 
 	prompt=new QCheckBox(_("Enter LILO &prompt automatically"), this);
 	QWhatsThis::add(prompt, _("If this box is checked, LILO goes to the LILO prompt whether or not a key is pressed. If it is turned off, LILO boots the default operating system unless shift is pressed (in that case, it goes to the LILO prompt).<br>This sets the <i>prompt</i> option in lilo.conf."));
+        connect(prompt, SIGNAL(clicked()), SIGNAL(configChanged()));
+
 	layout->addWidget(prompt);
-	
+
 	update();
 }
 void General::saveChanges()
@@ -151,11 +154,11 @@ void General::update()
 		if(drive->text(i)==boot)
 			drive->setCurrentItem(i);
 	timeout->setValue(atoi(lilo->defaults.get("timeout")));
-	compact->setChecked(!lilo->defaults.grep("[ \t]*compact[ \t]*$").empty());
-	linear->setChecked(!lilo->defaults.grep("[ \t]*linear[ \t]*$").empty());
-	lock->setChecked(!lilo->defaults.grep("[ \t]*lock[ \t]*$").empty());
-	restricted->setChecked(!lilo->defaults.grep("[ \t]*restricted[ \t]*$").empty());
-	String pw=lilo->defaults.grep("[ \t]*password[ \t]*=.*");
+	compact->setChecked(!lilo->defaults.grep("^[ \t]*compact[ \t]*$").empty());
+	linear->setChecked(!lilo->defaults.grep("^[ \t]*linear[ \t]*$").empty());
+	lock->setChecked(!lilo->defaults.grep("^[ \t]*lock[ \t]*$").empty());
+	restricted->setChecked(!lilo->defaults.grep("^[ \t]*restricted[ \t]*$").empty());
+	String pw=lilo->defaults.grep("^[ \t]*password[ \t]*=.*");
 	use_password->setChecked(!pw.empty());
 	if(!pw.empty())
 		password->setText(lilo->defaults.get("password").cstr());
@@ -172,9 +175,24 @@ void General::update()
 				break;
 			}
 		}
-	prompt->setChecked(!lilo->defaults.grep("[ \t]*prompt[ \t]*$").empty());
+	prompt->setChecked(!lilo->defaults.grep("^[ \t]*prompt[ \t]*$").empty());
 }
 void General::check_pw()
 {
 	password->setEnabled(restricted->isChecked() || use_password->isChecked());
 }
+
+void General::makeReadOnly()
+{
+    drive->setEnabled( false );
+    timeout->setEnabled( false );
+    linear->setEnabled( false );
+    compact->setEnabled( false );
+    lock->setEnabled( false );
+    restricted->setEnabled( false );
+    use_password->setEnabled( false );
+    password->setEnabled( false );
+    vga->setEnabled( false );
+    prompt->setEnabled( false );
+
+}
