@@ -1,4 +1,4 @@
-#include <kuniqueapp.h>
+#include <kuniqueapplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <stdlib.h>
