@@ -56,7 +56,7 @@ void PamView::initServices()
 
   if (!d.exists()) {
     KMessageBox::error(this, i18n("/etc/pam.d directory does not exist.\n"
-				  "Your system either does not have PAM support,\n"
+				  "Either your system does not have PAM support "
 				  "or there is some other configuration problem."));
     exit(1);
   }
