@@ -1,3 +1,4 @@
+#include <qstringlist.h>
 #include "ppitem.h"
 
 PamPropertiesItem::PamPropertiesItem(QString fileName, 
@@ -5,9 +6,13 @@ PamPropertiesItem::PamPropertiesItem(QString fileName,
 				     QListView *parent)
   : QListViewItem(parent)
 {
-  category = properties[0];
-  level = properties[1];
-  lib = properties[2];
+  int i = properties.count();
+  if (i > 0)
+     category = properties[0];
+  if (i > 1)
+     level = properties[1];
+  if (i > 2)
+     lib = properties[2];
 
   setText(0, category);
   setText(1, level);
